@@ -27,8 +27,8 @@ const Domparser = imports.xmldom.domparser;
 var GpxShapeLayer = GObject.registerClass(
 class GpxShapeLayer extends ShapeLayer.ShapeLayer {
 
-    constructor(params) {
-        super.construct(params);
+    _init(params) {
+        super._init(params);
 
         this._mapSource = new GeoJSONSource.GeoJSONSource({
             mapView: this._mapView,
