@@ -17,27 +17,25 @@
  * Author: Hashem Nasarat <hashem@riseup.net>
  */
 
-const Lang = imports.lang;
+const GObject = imports.gi.GObject;
 
 const GeoJSONSource = imports.geoJSONSource;
 const ShapeLayer = imports.shapeLayer;
 const Togeojson = imports.togeojson.togeojson;
 const Domparser = imports.xmldom.domparser;
 
-var KmlShapeLayer = new Lang.Class({
-    Name: 'KmlShapeLayer',
-    Extends: ShapeLayer.ShapeLayer,
-
-    _init: function(params) {
-        this.parent(params);
+var KmlShapeLayer = GObject.registerClass(
+class KmlShapeLayer extends ShapeLayer.ShapeLayer {
+    _init(params) {
+        super._init(params);
 
         this._mapSource = new GeoJSONSource.GeoJSONSource({
             mapView: this._mapView,
             markerLayer: this._markerLayer
         });
-    },
+    }
 
-    _parseContent: function() {
+    _parseContent() {
         let s = this._fileContents.toString();
         let parser = new Domparser.DOMParser();
         let json = Togeojson.toGeoJSON.kml(parser.parseFromString(s));
@@ -47,3 +45,6 @@ var KmlShapeLayer = new Lang.Class({
 
 KmlShapeLayer.mimeTypes = ['application/vnd.google-earth.kml+xml'];
 KmlShapeLayer.displayName = 'KML';
+KmlShapeLayer.createInstance = function(params) {
+    return new KmlShapeLayer(params);
+};
