@@ -19,8 +19,6 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const Lang = imports.lang;
-
 const Champlain = imports.gi.Champlain;
 const GLib = imports.gi.GLib;
 const Soup = imports.gi.Soup;
@@ -122,46 +120,41 @@ const NUM_STOPS_TO_TRY = 5;
 // gap to use when fetching additional routes
 const GAP_BEFORE_MORE_RESULTS = 120;
 
-var OpenTripPlanner = new Lang.Class({
-    Name: 'OpenTripPlanner',
+var OpenTripPlanner = class OpenTripPlanner {
 
-    _init: function(params) {
+    constructor(params) {
         this._session = new Soup.Session();
         /* initially set routers as updated far back in the past to force
          * a download when first request
          */
         this._routersUpdatedTimestamp = 0;
         this._query = params.query;
-        delete params.query;
         this._graphHopper = params.graphHopper;
-        delete params.graphHopper;
         this._plan = new TransitPlan.Plan();
         this._baseUrl = this._getBaseUrl();
         this._walkingRoutes = [];
         this._extendPrevious = false;
-
-        this.parent(params);
-    },
+    }
 
     get plan() {
         return this._plan;
-    },
+    }
 
     get enabled() {
         return this._baseUrl !== null;
-    },
+    }
 
-    fetchFirstResults: function() {
+    fetchFirstResults() {
         this._extendPrevious = false;
         this._fetchRoute();
-    },
+    }
 
-    fetchMoreResults: function() {
+    fetchMoreResults() {
         this._extendPrevious = true;
         this._fetchRoute();
-    },
+    }
 
-    _getBaseUrl: function() {
+    _getBaseUrl() {
         let debugUrl = GLib.getenv('OTP_BASE_URL');
 
         if (debugUrl) {
@@ -176,16 +169,16 @@ var OpenTripPlanner = new Lang.Class({
                 return null;
             }
         }
-    },
+    }
 
-    _getRouterUrl: function(router) {
+    _getRouterUrl(router) {
         if (!router || router.length === 0)
             router = 'default';
 
         return this._baseUrl + '/routers/' + router;
-    },
+    }
 
-    _fetchRouters: function(callback) {
+    _fetchRouters(callback) {
         let currentTime = (new Date()).getTime();
 
         if (currentTime - this._routersUpdatedTimestamp < ROUTERS_TIMEOUT) {
@@ -195,7 +188,7 @@ var OpenTripPlanner = new Lang.Class({
             let request = new Soup.Message({ method: 'GET', uri: uri });
 
             request.request_headers.append('Accept', 'application/json');
-            this._session.queue_message(request, (function(obj, message) {
+            this._session.queue_message(request, (obj, message) => {
                 if (message.status_code !== Soup.Status.OK) {
                     callback(false);
                     return;
@@ -209,14 +202,14 @@ var OpenTripPlanner = new Lang.Class({
                     Utils.debug('Failed to parse router information');
                     callback(false);
                 }
-            }).bind(this));
+            });
         }
-    },
+    }
 
-    _getRoutersForPlace: function(place) {
+    _getRoutersForPlace(place) {
         let routers = [];
 
-        this._routers.routerInfo.forEach((function(routerInfo) {
+        this._routers.routerInfo.forEach((routerInfo) => {
             /* TODO: only check bounding rectangle for now
              * should we try to do a finer-grained check using the bounding
              * polygon (if OTP gives one for the routers).
@@ -228,22 +221,22 @@ var OpenTripPlanner = new Lang.Class({
                 place.location.longitude >= routerInfo.lowerLeftLongitude &&
                 place.location.longitude <= routerInfo.upperRightLongitude)
                 routers.push(routerInfo.routerId);
-        }));
+        });
 
         return routers;
-    },
+    }
 
     /* Note: this is theoretically slow (O(n*m)), but we will have filtered
      * possible routers for the starting and ending query point, so they should
      * be short (in many cases just one element)
      */
-    _routerIntersection: function(routers1, routers2) {
+    _routerIntersection(routers1, routers2) {
         return routers1.filter(function(n) {
             return routers2.indexOf(n) != -1;
         });
-    },
+    }
 
-    _getMode: function(routeType) {
+    _getMode(routeType) {
         switch (routeType) {
         case TransitPlan.RouteType.TRAM:
             return 'TRAM';
@@ -258,17 +251,17 @@ var OpenTripPlanner = new Lang.Class({
         default:
             throw new Error('unhandled route type');
         }
-    },
+    }
 
-    _getModes: function(options) {
-        let modes = options.transitTypes.map((function(transitType) {
+    _getModes(options) {
+        let modes = options.transitTypes.map((transitType) => {
             return this._getMode(transitType);
-        }).bind(this));
+        });
 
         return modes.join(',');
-    },
+    }
 
-    _selectBestStopRecursive: function(stops, index, stopIndex, callback) {
+    _selectBestStopRecursive(stops, index, stopIndex, callback) {
         if (index < stops.length) {
             let points = this._query.filledPoints;
             let stop = stops[index];
@@ -282,21 +275,21 @@ var OpenTripPlanner = new Lang.Class({
                                               callback);
             } else if (stopIndex === 0) {
                 this._fetchWalkingRoute([points[0], stopPoint],
-                                        (function(route) {
+                                        (route) => {
                     /* if we couldn't find an exact walking route, go with the
                      * "as the crow flies" distance */
                     if (route)
                         stop.dist = route.distance;
                     this._selectBestStopRecursive(stops, index + 1, stopIndex,
                                                   callback);
-                }).bind(this));
+                });
             } else if (stopIndex === points.length - 1) {
-                this._fetchWalkingRoute([stopPoint, points.last()], (function(route) {
+                this._fetchWalkingRoute([stopPoint, points.last()], (route) => {
                     if (route)
                         stop.dist = route.distance;
                     this._selectBestStopRecursive(stops, index + 1, stopIndex,
                                                   callback);
-                }).bind(this));
+                });
             } else {
                 /* for intermediate stops just return the one geographically
                  * closest */
@@ -308,32 +301,30 @@ var OpenTripPlanner = new Lang.Class({
              * distances */
             stops.sort(this._sortTransitStops);
             Utils.debug('refined stops: ');
-            stops.forEach(function(stop) {
-                Utils.debug(JSON.stringify(stop, '', 2));
-            });
+            stops.forEach((stop) => Utils.debug(JSON.stringify(stop, '', 2)));
             callback(stops[0]);
         }
-    },
+    }
 
     /* stopIndex here is the index of stop (i.e. starting point, intermediate
      * stop, final stop
      */
-    _selectBestStop: function(stops, stopIndex, callback) {
+    _selectBestStop(stops, stopIndex, callback) {
         this._selectBestStopRecursive(stops, 0, stopIndex, callback);
-    },
+    }
 
-    _sortTransitStops: function(s1, s2) {
+    _sortTransitStops(s1, s2) {
         return s1.dist > s2.dist;
-    },
+    }
 
-    _fetchRoutesForStop: function(router, stop, callback) {
+    _fetchRoutesForStop(router, stop, callback) {
         let query = new HTTP.Query();
         let uri = new Soup.URI(this._getRouterUrl(router) +
                                '/index/stops/' + stop.id + '/routes');
         let request = new Soup.Message({ method: 'GET', uri: uri });
 
         request.request_headers.append('Accept', 'application/json');
-        this._session.queue_message(request, (function(obj, message) {
+        this._session.queue_message(request, (obj, message) => {
             if (message.status_code !== Soup.Status.OK) {
                 Utils.debug('Failed to get routes for stop');
                 this._reset();
@@ -343,10 +334,10 @@ var OpenTripPlanner = new Lang.Class({
                 Utils.debug('Routes for stop: ' + stop + ': ' + JSON.stringify(routes));
                 callback(routes);
             }
-        }).bind(this));
-    },
+        });
+    }
 
-    _routeMatchesSelectedModes: function(route) {
+    _routeMatchesSelectedModes(route) {
         let desiredTransitTypes = this._query.transitOptions.transitTypes;
 
         for (let i = 0; i < desiredTransitTypes.length; i++) {
@@ -366,13 +357,13 @@ var OpenTripPlanner = new Lang.Class({
         }
 
         return false;
-    },
+    }
 
-    _filterStopsRecursive: function(router, stops, index, filteredStops, callback) {
+    _filterStopsRecursive(router, stops, index, filteredStops, callback) {
         if (index < stops.length) {
             let stop = stops[index];
 
-            this._fetchRoutesForStop(router, stop, (function(routes) {
+            this._fetchRoutesForStop(router, stop, (routes) => {
                 for (let i = 0; i < routes.length; i++) {
                     let route = routes[i];
 
@@ -383,17 +374,17 @@ var OpenTripPlanner = new Lang.Class({
                 }
                 this._filterStopsRecursive(router, stops, index + 1,
                                            filteredStops, callback);
-            }).bind(this));
+            });
         } else {
             callback(filteredStops);
         }
-    },
+    }
 
-    _filterStops: function(router, stops, callback) {
+    _filterStops(router, stops, callback) {
         this._filterStopsRecursive(router, stops, 0, [], callback);
-    },
+    }
 
-    _fetchTransitStopsRecursive: function(router, index, result, callback) {
+    _fetchTransitStopsRecursive(router, index, result, callback) {
         let points = this._query.filledPoints;
 
         if (index < points.length) {
@@ -407,7 +398,7 @@ var OpenTripPlanner = new Lang.Class({
             let request = new Soup.Message({ method: 'GET', uri: uri });
 
             request.request_headers.append('Accept', 'application/json');
-            this._session.queue_message(request, (function(obj, message) {
+            this._session.queue_message(request, (obj, message) => {
                 if (message.status_code !== Soup.Status.OK) {
                     Utils.debug('Failed to get stop for search point ' + point);
                     this._reset();
@@ -425,13 +416,13 @@ var OpenTripPlanner = new Lang.Class({
                         stops = stops.splice(0, NUM_STOPS_TO_TRY);
 
                         Utils.debug('stops: ' + JSON.stringify(stops, '', 2));
-                        this._selectBestStop(stops, index, (function(stop) {
+                        this._selectBestStop(stops, index, (stop) => {
                             result.push(stop);
                             this._fetchTransitStopsRecursive(router, index + 1,
                                                              result, callback);
-                        }).bind(this));
+                        });
                     } else {
-                        this._filterStops(router, stops, (function(filteredStops) {
+                        this._filterStops(router, stops, (filteredStops) => {
                             filteredStops.sort(this._sortTransitStops);
                             filteredStops = filteredStops.splice(0, NUM_STOPS_TO_TRY);
 
@@ -441,42 +432,42 @@ var OpenTripPlanner = new Lang.Class({
                                 return;
                             }
 
-                            this._selectBestStop(filteredStops, index, (function(stop) {
+                            this._selectBestStop(filteredStops, index, (stop) => {
                                 result.push(stop);
                                 this._fetchTransitStopsRecursive(router, index + 1,
                                                                  result, callback);
-                            }).bind(this));
-                        }).bind(this));
+                            });
+                        });
                     }
                 }
-            }).bind(this));
+            });
         } else {
             callback(result);
         }
-    },
+    }
 
-    _fetchTransitStops: function(router, callback) {
+    _fetchTransitStops(router, callback) {
         this._fetchTransitStopsRecursive(router, 0, [], callback);
-    },
+    }
 
     // get a time suitably formatted for the OpenTripPlanner query param
-    _formatTime: function(time, offset) {
+    _formatTime(time, offset) {
         let utcTimeWithOffset = (time + offset) / 1000;
         let date = GLib.DateTime.new_from_unix_utc(utcTimeWithOffset);
 
         return date.format('%R');
-    },
+    }
 
     // get a date suitably formatted for the OpenTripPlanner query param
-    _formatDate: function(time, offset) {
+    _formatDate(time, offset) {
         let utcTimeWithOffset = (time + offset) / 1000;
         let date = GLib.DateTime.new_from_unix_utc(utcTimeWithOffset);
 
         return date.format('%F');
-    },
+    }
 
     // create parameter map for the request, given query and options
-    _createParams: function(stops) {
+    _createParams(stops) {
         let params = { fromPlace: stops[0].id,
                        toPlace: stops.last().id };
         let intermediatePlaces = [];
@@ -541,10 +532,10 @@ var OpenTripPlanner = new Lang.Class({
             params.mode = this._getModes(options);
 
         return params;
-    },
+    }
 
-    _fetchRoutesForRouter: function(router, callback) {
-        this._fetchTransitStops(router, (function(stops) {
+    _fetchRoutesForRouter(router, callback) {
+        this._fetchTransitStops(router, (stops) => {
             let points = this._query.filledPoints;
 
             if (!stops) {
@@ -570,7 +561,7 @@ var OpenTripPlanner = new Lang.Class({
             let request = new Soup.Message({ method: 'GET', uri: uri });
 
             request.request_headers.append('Accept', 'application/json');
-            this._session.queue_message(request, (function(obj, message) {
+            this._session.queue_message(request, (obj, message) => {
                 if (message.status_code !== Soup.Status.OK) {
                     Utils.debug('Failed to get route plan from router ' +
                                 routers[index] + ' ' + message);
@@ -578,45 +569,45 @@ var OpenTripPlanner = new Lang.Class({
                 } else {
                     callback(JSON.parse(message.response_body.data));
                 }
-            }).bind(this));
-        }).bind(this));
-    },
+            });
+        });
+    }
 
-    _fetchRoutesRecursive: function(routers, index, result, callback) {
+    _fetchRoutesRecursive(routers, index, result, callback) {
         if (index < routers.length) {
             let router = routers[index];
 
-            this._fetchRoutesForRouter(router, (function(response) {
+            this._fetchRoutesForRouter(router, (response) => {
                 if (response) {
                     Utils.debug('plan: ' + JSON.stringify(response, '', 2));
                     result.push(response);
                 }
 
                 this._fetchRoutesRecursive(routers, index + 1, result, callback);
-            }).bind(this));
+            });
         } else {
             callback(result);
         }
-    },
+    }
 
-    _fetchRoutes: function(routers, callback) {
+    _fetchRoutes(routers, callback) {
         this._fetchRoutesRecursive(routers, 0, [], callback);
-    },
+    }
 
-    _reset: function() {
+    _reset() {
         this._extendPrevious = false;
         if (this._query.latest)
             this._query.latest.place = null;
         else
             this.plan.reset();
-    },
+    }
 
     /* Indicate that no routes where found, either shows the "No route found"
      * notification, or in case of loading additional (later/earlier) results,
      * indicate no such where found, so that the sidebar can disable the
      * "load more" functionallity as appropriate.
      */
-    _noRouteFound: function() {
+    _noRouteFound() {
         if (this._extendPrevious) {
             let message = this._query.arriveBy ?
                           _("No earlier alternatives found.") :
@@ -628,24 +619,24 @@ var OpenTripPlanner = new Lang.Class({
             Application.notificationManager.showMessage(_("No route found."));
             this._reset();
         }
-    },
+    }
 
-    _fetchRoute: function() {
-        this._fetchRouters((function(success) {
+    _fetchRoute() {
+        this._fetchRouters((success) => {
             if (success) {
                 let points = this._query.filledPoints;
                 let routers = this._getRoutersForPoints(points);
 
                 if (routers.length > 0) {
-                    this._fetchRoutes(routers, (function(routes) {
+                    this._fetchRoutes(routers, (routes) => {
                         let itineraries = [];
-                        routes.forEach((function(plan) {
+                        routes.forEach((plan) => {
                             if (plan.plan && plan.plan.itineraries) {
                                 itineraries =
                                     itineraries.concat(
                                         this._createItineraries(plan.plan.itineraries));
                             }
-                        }).bind(this));
+                        });
 
                         if (itineraries.length === 0) {
                             /* don't reset query points, unlike for turn-based
@@ -655,7 +646,7 @@ var OpenTripPlanner = new Lang.Class({
                         } else {
                             this._recalculateItineraries(itineraries);
                         }
-                    }).bind(this));
+                    });
 
                 } else {
                     Application.notificationManager.showMessage(_("No timetable data found for this route."));
@@ -665,29 +656,29 @@ var OpenTripPlanner = new Lang.Class({
                 Application.notificationManager.showMessage(_("Route request failed."));
                 this._reset();
             }
-        }).bind(this));
-    },
+        });
+    }
 
-    _isOnlyWalkingItinerary: function(itinerary) {
+    _isOnlyWalkingItinerary(itinerary) {
         return itinerary.legs.length === 1 && !itinerary.legs[0].transit;
-    },
+    }
 
-    _recalculateItineraries: function(itineraries) {
+    _recalculateItineraries(itineraries) {
         // filter out itineraries with only walking
         let newItineraries = [];
 
-        itineraries.forEach((function(itinerary) {
+        itineraries.forEach((itinerary) => {
             if (!this._isOnlyWalkingItinerary(itinerary))
                 newItineraries.push(itinerary);
-        }).bind(this));
+        });
 
         /* TODO: should we always calculate a walking itinerary to put at the
          * top if the total distance is below some threashhold?
          */
         this._recalculateItinerariesRecursive(newItineraries, 0);
-    },
+    }
 
-    _isItineraryRealistic: function(itinerary) {
+    _isItineraryRealistic(itinerary) {
         for (let i = 0; i < itinerary.legs.length; i++) {
             let leg = itinerary.legs[i];
 
@@ -713,14 +704,14 @@ var OpenTripPlanner = new Lang.Class({
         }
 
         return true;
-    },
+    }
 
-    _recalculateItinerariesRecursive: function(itineraries, index) {
+    _recalculateItinerariesRecursive(itineraries, index) {
         if (index < itineraries.length) {
-            this._recalculateItinerary(itineraries[index], (function(itinerary) {
+            this._recalculateItinerary(itineraries[index], (itinerary) => {
                 itineraries[index] = itinerary;
                 this._recalculateItinerariesRecursive(itineraries, index + 1);
-            }).bind(this));
+            });
         } else {
             /* filter out itineraries where there are intermediate walking legs
              * that are too narrow time-wise, this is nessesary since running
@@ -732,16 +723,14 @@ var OpenTripPlanner = new Lang.Class({
              */
             let filteredItineraries = [];
 
-            itineraries.forEach((function(itinerary) {
+            itineraries.forEach((itinerary) => {
                 if (this._isItineraryRealistic(itinerary) &&
                     !this._isOnlyWalkingItinerary(itinerary))
                     filteredItineraries.push(itinerary);
-            }).bind(this));
+            });
 
             if (filteredItineraries.length > 0) {
-                filteredItineraries.forEach((function(itinerary) {
-                    itinerary.adjustTimings();
-                }).bind(this));
+                filteredItineraries.forEach((itinerary) => itinerary.adjustTimings());
 
                 /* sort itineraries, by departure time ascending if querying
                  * by leaving time, by arrival time descending when querying
@@ -763,21 +752,21 @@ var OpenTripPlanner = new Lang.Class({
                 this._noRouteFound();
             }
         }
-    },
+    }
 
     // create a straight-line "as the crow flies" polyline between two places
-    _createStraightPolyline: function(fromLoc, toLoc) {
+    _createStraightPolyline(fromLoc, toLoc) {
         return [new Champlain.Coordinate({ latitude: fromLoc.latitude,
                                            longitude: fromLoc.longitude }),
                 new Champlain.Coordinate({ latitude: toLoc.latitude,
                                            longitude: toLoc.longitude })];
-    },
+    }
 
     /* Creates a new walking leg given start and end places, and a route
      * obtained from GraphHopper. If the route is undefined (which happens if
      * GraphHopper failed to obtain a walking route, approximate it with a
      * straight line. */
-    _createWalkingLeg: function(from, to, fromName, toName, route) {
+    _createWalkingLeg(from, to, fromName, toName, route) {
         let fromLocation = from.place.location;
         let toLocation = to.place.location;
         let fromCoordinate = [fromLocation.latitude, fromLocation.longitude];
@@ -800,12 +789,12 @@ var OpenTripPlanner = new Lang.Class({
                                      duration: duration,
                                      distance: distance,
                                      walkingInstructions: walkingInstructions });
-    },
+    }
 
     /* fetches walking route and stores the route for the given coordinate
      * pair to avoid requesting the same route over and over from GraphHopper
      */
-    _fetchWalkingRoute: function(points, callback) {
+    _fetchWalkingRoute(points, callback) {
         let index = points[0].place.location.latitude + ',' +
                     points[0].place.location.longitude + ';' +
                     points[1].place.location.latitude + ',' +
@@ -815,17 +804,16 @@ var OpenTripPlanner = new Lang.Class({
         if (!route) {
             this._graphHopper.fetchRouteAsync(points,
                                               RouteQuery.Transportation.PEDESTRIAN,
-                                              (function(newRoute)
-            {
+                                              (newRoute) => {
                 this._walkingRoutes[index] = newRoute;
                 callback(newRoute);
-            }).bind(this));
+            });
         } else {
             callback(route);
         }
-    },
+    }
 
-    _recalculateItinerary: function(itinerary, callback) {
+    _recalculateItinerary(itinerary, callback) {
         let from = this._query.filledPoints[0];
         let to = this._query.filledPoints.last();
 
@@ -834,7 +822,7 @@ var OpenTripPlanner = new Lang.Class({
              * leg is a non-transit (walking), recalculate the route in its entire
              * using walking
              */
-            this._fetchWalkingRoute(this._query.filledPoints, (function(route) {
+            this._fetchWalkingRoute(this._query.filledPoints, (route) => {
                 let leg = this._createWalkingLeg(from, to, from.place.name,
                                                  to.place.name, route);
                 let newItinerary =
@@ -842,7 +830,7 @@ var OpenTripPlanner = new Lang.Class({
                                                duration: route.time / 1000,
                                                legs: [leg]});
                 callback(newItinerary);
-            }).bind(this));
+            });
         } else if (itinerary.legs.length === 1 && itinerary.legs[0].transit) {
             // special case if there is extactly one transit leg
             let leg = itinerary.legs[0];
@@ -860,28 +848,28 @@ var OpenTripPlanner = new Lang.Class({
                 /* add an extra walking leg to both the beginning and end of the
                  * itinerary
                  */
-                this._fetchWalkingRoute([from, startLeg], (function(firstRoute) {
+                this._fetchWalkingRoute([from, startLeg], (firstRoute) => {
                     let firstLeg =
                         this._createWalkingLeg(from, startLeg, from.place.name,
                                                leg.from, firstRoute);
-                    this._fetchWalkingRoute([endLeg, to], (function(lastRoute) {
+                    this._fetchWalkingRoute([endLeg, to], (lastRoute) => {
                         let lastLeg = this._createWalkingLeg(endLeg, to, leg.to,
                                                              to.place.name,
                                                              lastRoute);
                         itinerary.legs.unshift(firstLeg);
                         itinerary.legs.push(lastLeg);
                         callback(itinerary);
-                    }).bind(this));
-                }).bind(this));
+                    });
+                });
             } else if (endWalkDistance >= MIN_WALK_ROUTING_DISTANCE) {
                 // add an extra walking leg to the end of the itinerary
-                this._fetchWalkingRoute([endLeg, to], (function(lastRoute) {
+                this._fetchWalkingRoute([endLeg, to], (lastRoute) => {
                     let lastLeg =
                         this._createWalkingLeg(endLeg, to, leg.to,
                                                to.place.name, lastRoute);
                     itinerary.legs.push(lastLeg);
                     callback(itinerary);
-                }).bind(this));
+                });
             } else {
                 /* if only there's only a walking leg to be added to the start
                  * let the recursive routine dealing with multi-leg itineraries
@@ -897,9 +885,9 @@ var OpenTripPlanner = new Lang.Class({
              */
             this._recalculateItineraryRecursive(itinerary, 0, callback);
         }
-    },
+    }
 
-    _createQueryPointForCoord: function(coord) {
+    _createQueryPointForCoord(coord) {
         let location = new Location.Location({ latitude: coord[0],
                                                longitude: coord[1],
                                                accuracy: 0 });
@@ -908,9 +896,9 @@ var OpenTripPlanner = new Lang.Class({
 
         point.place = place;
         return point;
-    },
+    }
 
-    _recalculateItineraryRecursive: function(itinerary, index, callback) {
+    _recalculateItineraryRecursive(itinerary, index, callback) {
         if (index < itinerary.legs.length) {
             let leg = itinerary.legs[index];
             if (index === 0) {
@@ -955,14 +943,14 @@ var OpenTripPlanner = new Lang.Class({
                         itinerary.legs.splice(index + 1, index + 1);
                     }
 
-                    this._fetchWalkingRoute([from, to], (function(route) {
+                    this._fetchWalkingRoute([from, to], (route) => {
                         let newLeg =
                             this._createWalkingLeg(from, to, from.place.name,
                                                    toName, route);
                         itinerary.legs[index] = newLeg;
                         this._recalculateItineraryRecursive(itinerary, index + 1,
                                                             callback);
-                    }).bind(this));
+                    });
                 } else {
                     /* introduce an additional walking leg calculated
                      * by GH in case the OTP starting point as far enough from
@@ -974,7 +962,7 @@ var OpenTripPlanner = new Lang.Class({
                     let distance = fromLoc.get_distance_from(toLoc) * 1000;
 
                     if (distance >= MIN_WALK_ROUTING_DISTANCE) {
-                        this._fetchWalkingRoute([from, to], (function(route) {
+                        this._fetchWalkingRoute([from, to], (route) => {
                             let newLeg =
                                 this._createWalkingLeg(from, to, from.place.name,
                                                        leg.from, route);
@@ -985,7 +973,7 @@ var OpenTripPlanner = new Lang.Class({
                             this._recalculateItineraryRecursive(itinerary,
                                                                 index + 2,
                                                                 callback);
-                        }).bind(this));
+                        });
                     } else {
                         this._recalculateItineraryRecursive(itinerary, index + 1,
                                                             callback);
@@ -1035,7 +1023,7 @@ var OpenTripPlanner = new Lang.Class({
                         insertIndex = index;
                     }
                     let from = this._createQueryPointForCoord(finalTransitLeg.fromCoordinate);
-                    this._fetchWalkingRoute([from, to], (function(route) {
+                    this._fetchWalkingRoute([from, to], (route) => {
                         let newLeg =
                             this._createWalkingLeg(from, to,
                                                    finalTransitLeg.from,
@@ -1044,7 +1032,7 @@ var OpenTripPlanner = new Lang.Class({
                         this._recalculateItineraryRecursive(itinerary,
                                                             insertIndex + 1,
                                                             callback);
-                    }).bind(this));
+                    });
                 } else {
                     /* introduce an additional walking leg calculated by GH in
                      * case the OTP end point as far enough from the original
@@ -1056,7 +1044,7 @@ var OpenTripPlanner = new Lang.Class({
                     let distance = fromLoc.get_distance_from(toLoc) * 1000;
 
                     if (distance >= MIN_WALK_ROUTING_DISTANCE) {
-                        this._fetchWalkingRoute([from, to], (function(route) {
+                        this._fetchWalkingRoute([from, to], (route) => {
                             let newLeg =
                                 this._createWalkingLeg(from, to, leg.to,
                                                        to.place.name, route);
@@ -1067,7 +1055,7 @@ var OpenTripPlanner = new Lang.Class({
                             this._recalculateItineraryRecursive(itinerary,
                                                                  index + 2,
                                                                  callback);
-                        }).bind(this));
+                        });
                     } else {
                         this._recalculateItineraryRecursive(itinerary, index + 1,
                                                             callback);
@@ -1092,14 +1080,14 @@ var OpenTripPlanner = new Lang.Class({
                         itinerary.legs.splice(index + 1, index + 1);
                     }
 
-                    this._fetchWalkingRoute([from, to], (function(route) {
+                    this._fetchWalkingRoute([from, to], (route) => {
                         let newLeg = this._createWalkingLeg(from, to, leg.from,
                                                             leg.to, route);
                         itinerary.legs[index] = newLeg;
                         this._recalculateItineraryRecursive(itinerary,
                                                             index + 1,
                                                             callback);
-                    }).bind(this));
+                    });
                 } else {
                     this._recalculateItineraryRecursive(itinerary, index + 1,
                                                         callback);
@@ -1108,9 +1096,9 @@ var OpenTripPlanner = new Lang.Class({
         } else {
             callback(itinerary);
         }
-    },
+    }
 
-    _getRoutersForPoints: function(points) {
+    _getRoutersForPoints(points) {
         let startRouters = this._getRoutersForPlace(points[0].place);
         let endRouters =
             this._getRoutersForPlace(points.last().place);
@@ -1119,31 +1107,27 @@ var OpenTripPlanner = new Lang.Class({
             this._routerIntersection(startRouters, endRouters);
 
         return intersectingRouters;
-    },
+    }
 
-    _createItineraries: function(itineraries) {
-        return itineraries.map((function(itinerary) {
-                                    return this._createItinerary(itinerary);
-                                }).bind(this));
-    },
+    _createItineraries(itineraries) {
+        return itineraries.map((itinerary) => this._createItinerary(itinerary));
+    }
 
-    _createItinerary: function(itinerary) {
+    _createItinerary(itinerary) {
         let legs = this._createLegs(itinerary.legs);
         return new TransitPlan.Itinerary({ duration:  itinerary.duration,
                                            transfers: itinerary.transfers,
                                            departure: itinerary.startTime,
                                            arrival:   itinerary.endTime,
                                            legs:      legs});
-    },
+    }
 
-    _createLegs: function(legs) {
-        return legs.map((function(leg) {
-            return this._createLeg(leg);
-        }).bind(this));
-    },
+    _createLegs(legs) {
+        return legs.map((leg) => this._createLeg(leg));
+    }
 
     /* check if a string is a valid hex RGB string */
-    _isValidHexColor: function(string) {
+    _isValidHexColor(string) {
         if (string && string.length === 6) {
             let regex = /^[A-Fa-f0-9]/;
 
@@ -1151,9 +1135,9 @@ var OpenTripPlanner = new Lang.Class({
         }
 
         return false;
-    },
+    }
 
-    _createLeg: function(leg) {
+    _createLeg(leg) {
         let polyline = EPAF.decode(leg.legGeometry.points);
         let intermediateStops =
             this._createIntermediateStops(leg);
@@ -1193,20 +1177,18 @@ var OpenTripPlanner = new Lang.Class({
                                      color:                color,
                                      textColor:            textColor,
                                      tripShortName:        leg.tripShortName });
-    },
+    }
 
-    _createIntermediateStops: function(leg) {
+    _createIntermediateStops(leg) {
         let stops = leg.intermediateStops;
-        return stops.map((function(stop) {
-            return this._createIntermediateStop(stop, leg);
-        }).bind(this));
-    },
+        return stops.map((stop) => this._createIntermediateStop(stop, leg));
+    }
 
-    _createIntermediateStop: function(stop, leg) {
+    _createIntermediateStop(stop, leg) {
         return new TransitPlan.Stop({ name:       stop.name,
                                       arrival:    stop.arrival,
                                       departure:  stop.departure,
                                       agencyTimezoneOffset: leg.agencyTimeZoneOffset,
                                       coordinate: [stop.lat, stop.lon] });
     }
-});
+};
