@@ -22,7 +22,6 @@
 
 const _ = imports.gettext.gettext;
 
-const Lang = imports.lang;
 const Maps = imports.gi.GnomeMaps;
 const Rest = imports.gi.Rest;
 const Secret = imports.gi.Secret;
@@ -45,10 +44,9 @@ const SECRET_SCHEMA = new Secret.Schema("org.gnome.Maps",
     }
 );
 
-var OSMConnection = new Lang.Class({
-    Name: 'OSMConnection',
+var OSMConnection = class OSMConnection {
 
-    _init: function(params) {
+    constructor() {
         this._session = new Soup.Session();
 
         /* OAuth proxy used for making OSM uploads */
@@ -56,18 +54,18 @@ var OSMConnection = new Lang.Class({
                                               BASE_URL + '/' + API_VERSION,
                                               false);
         Maps.osm_init();
-    },
+    }
 
-    getOSMObject: function(type, id, callback, cancellable) {
+    getOSMObject(type, id, callback, cancellable) {
         let url = this._getQueryUrl(type, id);
         let uri = new Soup.URI(url);
         let request = new Soup.Message({ method: 'GET', uri: uri });
 
-        cancellable.connect((function() {
+        cancellable.connect(() => {
             this._session.cancel_message(request, Soup.STATUS_CANCELLED);
-        }).bind(this));
+        });
 
-        this._session.queue_message(request, (function(obj, message) {
+        this._session.queue_message(request, (obj, message) => {
             if (message.status_code !== Soup.Status.OK) {
                 callback(false, message.status_code, null, type, null);
                 return;
@@ -81,30 +79,30 @@ var OSMConnection = new Lang.Class({
                 Utils.debug(e);
                 callback(false, message.status_code, null, type, e);
             }
-        }).bind(this));
-    },
+        });
+    }
 
-    _getQueryUrl: function(type, id) {
+    _getQueryUrl(type, id) {
         return BASE_URL + '/' + API_VERSION + '/' + type + '/' + id;
-    },
+    }
 
-    openChangeset: function(comment, callback) {
+    openChangeset(comment, callback) {
         /* we assume that this would only be called if there's already been an
            OAuth access token enrolled, so, if the currently instanciated
            proxy instance doesn't have a token set, we could safely count on
            it being present in the keyring */
         if (this._callProxy.get_token() === null) {
-            Secret.password_lookup(SECRET_SCHEMA, {}, null, function(s, res) {
+            Secret.password_lookup(SECRET_SCHEMA, {}, null, (s, res) => {
                 this._onPasswordLookedUp(res,
                                          comment,
                                          callback);
-            }.bind(this));
+            });
         } else {
             this._doOpenChangeset(comment, callback);
         }
-    },
+    }
 
-    _onPasswordLookedUp: function(result, comment, callback) {
+    _onPasswordLookedUp(result, comment, callback) {
         let password = Secret.password_lookup_finish(result);
 
         if (password) {
@@ -117,9 +115,9 @@ var OSMConnection = new Lang.Class({
         } else {
             callback(false, null, null);
         }
-    },
+    }
 
-    _doOpenChangeset: function(comment, callback) {
+    _doOpenChangeset(comment, callback) {
         let changeset =
             Maps.OSMChangeset.new(comment, 'gnome-maps ' + pkg.version);
         let xml = changeset.serialize();
@@ -128,12 +126,11 @@ var OSMConnection = new Lang.Class({
         call.set_method('PUT');
         call.set_function('/changeset/create');
 
-        call.invoke_async(null, (function(call, res, userdata) {
-                    this._onChangesetOpened(call, callback);
-                                }).bind(this));
-    },
+        call.invoke_async(null, (call, res, userdata) =>
+                                { this._onChangesetOpened(call, callback); });
+    }
 
-    _onChangesetOpened: function(call, callback) {
+    _onChangesetOpened(call, callback) {
         if (call.get_status_code() !== Soup.Status.OK) {
             callback(false, call.get_status_code(), null);
             return;
@@ -141,9 +138,9 @@ var OSMConnection = new Lang.Class({
 
         let changesetId = parseInt(call.get_payload());
         callback(true, call.get_status_code(), changesetId);
-    },
+    }
 
-    uploadObject: function(object, type, changeset, callback) {
+    uploadObject(object, type, changeset, callback) {
         object.changeset = changeset;
 
         let xml = object.serialize();
@@ -152,21 +149,20 @@ var OSMConnection = new Lang.Class({
         call.set_method('PUT');
         call.set_function(this._getCreateOrUpdateFunction(object, type));
 
-        call.invoke_async(null, (function(call, res, userdata) {
-                    this._onObjectUploaded(call, callback);
-                                }).bind(this));
-    },
+        call.invoke_async(null, (call, res, userdata) =>
+                                { this._onObjectUploaded(call, callback); });
+    }
 
-    _onObjectUploaded: function(call, callback) {
+    _onObjectUploaded(call, callback) {
         if (call.get_status_code() !== Soup.Status.OK) {
             callback(false, call.get_status_code(), null);
             return;
         }
 
         callback(true, call.get_status_code(), call.get_payload());
-    },
+    }
 
-    deleteObject: function(object, type, changeset, callback) {
+    deleteObject(object, type, changeset, callback) {
         object.changeset = changeset;
 
         let xml = object.serialize();
@@ -175,64 +171,62 @@ var OSMConnection = new Lang.Class({
         call.set_method('DELETE');
         call.set_function(this._getDeleteFunction(object, type));
 
-        call.invoke_async(null, (function(call, res, userdata) {
-                    this._onObjectDeleted(call, callback);
-                                }).bind(this));
-    },
+        call.invoke_async(null, (call, res, userdata) =>
+                                { this._onObjectDeleted(call, callback); });
+    }
 
-    _onObjectDeleted: function(call, callback) {
+    _onObjectDeleted(call, callback) {
         if (call.get_status_code() !== Soup.Status.OK) {
             callback(false, call.get_status_code(), null);
             return;
         }
 
         callback(true, call.get_status_code(), call.get_payload());
-    },
+    }
 
-    closeChangeset: function(changesetId, callback) {
+    closeChangeset(changesetId, callback) {
         let call = this._callProxy.new_call();
         call.set_method('PUT');
         call.set_function(this._getCloseChangesetFunction(changesetId));
 
-        call.invoke_async(null, (function(call, res, userdata) {
-                    this._onChangesetClosed(call, callback);
-                                }).bind(this));
-    },
+        call.invoke_async(null, (call, res, userdata) =>
+                                { this._onChangesetClosed(call, callback); });
+    }
 
-    _onChangesetClosed: function(call, callback) {
+    _onChangesetClosed(call, callback) {
         if (call.get_status_code() !== Soup.Status.OK) {
             callback(false, call.get_status_code(), null);
             return;
         }
 
         callback(true, call.get_status_code(), call.get_payload());
-    },
+    }
 
-    _getCloseChangesetFunction: function(changesetId) {
+    _getCloseChangesetFunction(changesetId) {
         return '/changeset/' + changesetId + '/close';
-    },
+    }
 
-    _getCreateOrUpdateFunction: function(object, type) {
+    _getCreateOrUpdateFunction(object, type) {
         if (object.id)
             return type + '/' + object.id;
         else
             return type + '/create';
-    },
+    }
 
-    _getDeleteFunction: function(object, type) {
+    _getDeleteFunction(object, type) {
         return type + '/' + id;
-    },
+    }
 
-    requestOAuthToken: function(callback) {
+    requestOAuthToken(callback) {
         /* OAuth proxy used for enrolling access tokens */
         this._oauthProxy = Rest.OAuthProxy.new(CONSUMER_KEY, CONSUMER_SECRET,
                                                OAUTH_ENDPOINT_URL, false);
-        this._oauthProxy.request_token_async('request_token', 'oob', function(p, error, w, u) {
+        this._oauthProxy.request_token_async('request_token', 'oob', (p, error, w, u) => {
             this._onRequestOAuthToken(error, callback);
-        }.bind(this), this._oauthProxy, callback);
-    },
+        }, this._oauthProxy, callback);
+    }
 
-    _onRequestOAuthToken: function(error, callback) {
+    _onRequestOAuthToken(error, callback) {
         if (error) {
             Utils.debug(error);
             callback(false);
@@ -242,20 +236,20 @@ var OSMConnection = new Lang.Class({
         this._oauthToken = this._oauthProxy.get_token();
         this._oauthTokenSecret = this._oauthProxy.get_token_secret();
         callback(true);
-    },
+    }
 
-    authorizeOAuthToken: function(username, password, callback) {
+    authorizeOAuthToken(username, password, callback) {
         /* get login session ID */
         let loginUrl = LOGIN_URL + '?cookie_test=true';
         let uri = new Soup.URI(loginUrl);
         let msg = new Soup.Message({method: 'GET', uri: uri});
 
-        this._session.queue_message(msg, (function(obj, message) {
+        this._session.queue_message(msg, (obj, message) => {
             this._onLoginFormReceived(message, username, password, callback);
-        }).bind(this));
-    },
+        });
+    }
 
-    _onLoginFormReceived: function(message, username, password, callback) {
+    _onLoginFormReceived(message, username, password, callback) {
         if (message.status_code !== Soup.Status.OK) {
             callback(false);
             return;
@@ -272,9 +266,9 @@ var OSMConnection = new Lang.Class({
         }
 
         this._login(username, password, osmSessionID, osmSessionToken, callback);
-    },
+    }
 
-    _login: function(username, password, sessionId, token, callback) {
+    _login(username, password, sessionId, token, callback) {
         /* post login form */
         let msg = Soup.form_request_new_from_hash('POST', LOGIN_URL,
                                                   {username: username,
@@ -289,16 +283,16 @@ var OSMConnection = new Lang.Class({
         requestHeaders.append('Cookie', '_osm_session=' + sessionId);
         msg.flags |= Soup.MessageFlags.NO_REDIRECT;
 
-        this._session.queue_message(msg, (function(obj, message) {
+        this._session.queue_message(msg, (obj, message) => {
             if (message.status_code === Soup.Status.MOVED_TEMPORARILY)
                 this._fetchAuthorizeForm(username, sessionId, callback);
             else
                 callback(false, null);
-        }).bind(this));
+        });
 
-    },
+    }
 
-    _fetchAuthorizeForm: function(username, sessionId, callback) {
+    _fetchAuthorizeForm(username, sessionId, callback) {
         let auth = '/authorize?oauth_token=';
         let authorizeUrl = OAUTH_ENDPOINT_URL + auth + this._oauthToken;
         let uri = new Soup.URI(authorizeUrl);
@@ -307,17 +301,17 @@ var OSMConnection = new Lang.Class({
         msg.request_headers.append('Cookie',
                                    '_osm_session=' + sessionId +
                                    '; _osm_username=' + username);
-        this._session.queue_message(msg, (function(obj, message) {
+        this._session.queue_message(msg, (obj, message) => {
             if (message.status_code === Soup.Status.OK) {
                 let token = this._extractToken(message.response_body.data);
                 this._postAuthorizeForm(username, sessionId, token, callback);
             } else {
                 callback(false, null);
             }
-        }).bind(this));
-    },
+        });
+    }
 
-    _postAuthorizeForm: function(username, sessionId, token, callback) {
+    _postAuthorizeForm(username, sessionId, token, callback) {
         let authorizeUrl = OAUTH_ENDPOINT_URL + '/authorize';
         let msg = Soup.form_request_new_from_hash('POST', authorizeUrl, {
             oauth_token: this._oauthToken,
@@ -334,21 +328,21 @@ var OSMConnection = new Lang.Class({
                               '_osm_session=' + sessionId +
                               '; _osm_username=' + username);
 
-        this._session.queue_message(msg, (function(obj, message) {
+        this._session.queue_message(msg, (obj, message) => {
             if (msg.status_code === Soup.Status.OK) {
                 callback(true, message.response_body.data);
             } else
                 callback(false, null);
-        }).bind(this));
-    },
+        });
+    }
 
-    requestOAuthAccessToken: function(code, callback) {
-        this._oauthProxy.access_token_async('access_token', code, function(p, error, w, data) {
+    requestOAuthAccessToken(code, callback) {
+        this._oauthProxy.access_token_async('access_token', code, (p, error, w, data) => {
             this._onAccessOAuthToken(error, callback);
-        }.bind(this), this._oauthProxy, callback);
-    },
+        }, this._oauthProxy, callback);
+    }
 
-    _onAccessOAuthToken: function(error, callback) {
+    _onAccessOAuthToken(error, callback) {
         if (error) {
             callback(false);
             return;
@@ -363,19 +357,19 @@ var OSMConnection = new Lang.Class({
                               "OSM OAuth access token and secret",
                               this._oauthProxy.token + ":" +
                               this._oauthProxy.token_secret, null,
-                              function(source, result, userData) {
+                              (source, result, userData) => {
                                 this._onPasswordStored(result, callback);
-                              }.bind(this));
-    },
+                              });
+    }
 
-    _onPasswordStored: function(result, callback) {
+    _onPasswordStored(result, callback) {
         let res = false;
         if (result)
             res = Secret.password_store_finish(result);
         callback(res);
-    },
+    }
 
-    signOut: function() {
+    signOut() {
         /* clear token on call proxy, so it will use a new token if the user
            signs in again (with a new access token) during this running
            session */
@@ -384,14 +378,14 @@ var OSMConnection = new Lang.Class({
 
         Secret.password_clear(SECRET_SCHEMA, {}, null,
             this._onPasswordCleared.bind(this));
-    },
+    }
 
-    _onPasswordCleared: function(source, result) {
+    _onPasswordCleared(source, result) {
         Secret.password_clear_finish(result);
-    },
+    }
 
     /* extract the session ID from the login form response headers */
-    _extractOSMSessionID: function(responseHeaders) {
+    _extractOSMSessionID(responseHeaders) {
         let cookie = responseHeaders.get('Set-Cookie');
 
         if (cookie === null)
@@ -410,11 +404,11 @@ var OSMConnection = new Lang.Class({
         }
 
         return null;
-    },
+    }
 
     /* extract the authenticity token from the hidden input field of the login
        form */
-    _extractToken: function(messageBody) {
+    _extractToken(messageBody) {
         let regex = /.*authenticity_token.*value=\"([^\"]+)\".*/;
         let lines = messageBody.split('\n');
 
@@ -427,7 +421,7 @@ var OSMConnection = new Lang.Class({
 
         return null;
     }
-});
+};
 
 /*
  * Gets a status message (usually for an error case)
