@@ -25,7 +25,6 @@ const GObject = imports.gi.GObject;
 const Geocode = imports.gi.GeocodeGlib;
 const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 
 const Application = imports.application;
 const Location = imports.location;
@@ -34,9 +33,7 @@ const PlaceStore = imports.placeStore;
 const PlacePopover = imports.placePopover;
 const Utils = imports.utils;
 
-var PlaceEntry = new Lang.Class({
-    Name: 'PlaceEntry',
-    Extends: Gtk.SearchEntry,
+var PlaceEntry = GObject.registerClass({
     Properties: {
         'place': GObject.ParamSpec.object('place',
                                           'Place',
@@ -44,7 +41,8 @@ var PlaceEntry = new Lang.Class({
                                           GObject.ParamFlags.READABLE |
                                           GObject.ParamFlags.WRITABLE,
                                           Geocode.Place)
-    },
+    }
+}, class PlaceEntry extends Gtk.SearchEntry {
 
     set place(p) {
         if (!this._place && !p)
@@ -63,17 +61,17 @@ var PlaceEntry = new Lang.Class({
 
         this._place = p;
         this.notify('place');
-    },
+    }
 
     get place() {
         return this._place;
-    },
+    }
 
     get popover() {
         return this._popover;
-    },
+    }
 
-    _init: function(props) {
+    _init(props) {
         let numVisible = props.num_visible || 6;
         delete props.num_visible;
         this._mapView = props.mapView;
@@ -92,7 +90,7 @@ var PlaceEntry = new Lang.Class({
         this._matchRoute = props.matchRoute || false;
         delete props.matchRoute;
 
-        this.parent(props);
+        super._init(props);
 
         this._filter = new Gtk.TreeModelFilter({ child_model: Application.placeStore });
         this._filter.set_visible_func(this._completionVisibleFunc.bind(this));
@@ -100,7 +98,7 @@ var PlaceEntry = new Lang.Class({
         this._popover = this._createPopover(numVisible, maxChars);
 
         this.connect('activate', this._onActivate.bind(this));
-        this.connect('search-changed', (function() {
+        this.connect('search-changed', () => {
             if (this._cancellable)
                 this._cancellable.cancel();
 
@@ -116,50 +114,50 @@ var PlaceEntry = new Lang.Class({
                 this._popover.showCompletion();
             else
                 this._popover.hide();
-        }).bind(this));
+        });
 
         if (parseOnFocusOut) {
-            this.connect('focus-out-event', (function() {
+            this.connect('focus-out-event', () => {
                 this._parse();
                 return false;
-            }).bind(this));
+            });
         }
-    },
+    }
 
-    _locEquals: function(placeA, placeB) {
+    _locEquals(placeA, placeB) {
         if (!placeA.location || !placeB.location)
             return false;
 
         return (placeA.location.latitude === placeB.location.latitude &&
                 placeA.location.longitude === placeB.location.longitude);
-    },
+    }
 
-    _createPopover: function(numVisible, maxChars) {
+    _createPopover(numVisible, maxChars) {
         let popover = new PlacePopover.PlacePopover({ num_visible:   numVisible,
                                                       relative_to:   this,
                                                       maxChars:      maxChars});
 
-        this.connect('size-allocate', (function(widget, allocation) {
+        this.connect('size-allocate', (widget, allocation) => {
             // Magic number to make the alignment pixel perfect.
             let width_request = allocation.width + 20;
             popover.width_request = width_request;
-        }).bind(this));
+        });
 
-        popover.connect('selected', (function(widget, place) {
+        popover.connect('selected', (widget, place) => {
             this.place = place;
             popover.hide();
-        }).bind(this));
+        });
 
         return popover;
-    },
+    }
 
-    _refreshFilter: function() {
+    _refreshFilter() {
         /* Filter model based on input text */
         this._filter.refilter();
         this._popover.updateCompletion(this._filter, this.text);
-    },
+    }
 
-    _completionVisibleFunc: function(model, iter) {
+    _completionVisibleFunc(model, iter) {
         let place = model.get_value(iter, PlaceStore.Columns.PLACE);
         let type = model.get_value(iter, PlaceStore.Columns.TYPE);
 
@@ -170,9 +168,9 @@ var PlaceEntry = new Lang.Class({
             return place.match(this.text);
         else
             return false;
-    },
+    }
 
-    _parse: function() {
+    _parse() {
         if (this.text.length === 0) {
             this.place = null;
             return true;
@@ -199,9 +197,9 @@ var PlaceEntry = new Lang.Class({
         }
 
         return false;
-    },
+    }
 
-    _onActivate: function() {
+    _onActivate() {
         if (this._parse())
             return;
 
@@ -209,7 +207,7 @@ var PlaceEntry = new Lang.Class({
 
         this._popover.showSpinner();
         this._cancellable = new Gio.Cancellable();
-        Application.geocodeService.search(this.text, bbox, this._cancellable, (function(places) {
+        Application.geocodeService.search(this.text, bbox, this._cancellable, (places) => {
             if (!places) {
                 this.place = null;
                 this._popover.showNoResult();
@@ -217,6 +215,6 @@ var PlaceEntry = new Lang.Class({
             }
             this._popover.updateResult(places, this.text);
             this._popover.showResult();
-        }).bind(this));
+        });
     }
 });
