@@ -22,7 +22,6 @@ const GObject = imports.gi.GObject;
 const GdkPixbuf = imports.gi.GdkPixbuf;
 const Geocode = imports.gi.GeocodeGlib;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 
 const ContactPlace = imports.contactPlace;
 const Place = imports.place;
@@ -50,11 +49,10 @@ var Columns = {
     ADDED: 4
 };
 
-var PlaceStore = new Lang.Class({
-    Name: 'PlaceStore',
-    Extends: Gtk.ListStore,
+var PlaceStore = GObject.registerClass(
+class PlaceStore extends Gtk.ListStore {
 
-    _init: function(params) {
+    _init(params) {
         this._recentPlacesLimit = params.recentPlacesLimit;
         delete params.recentPlacesLimit;
 
@@ -67,7 +65,7 @@ var PlaceStore = new Lang.Class({
                                               _PLACES_STORE_FILE]);
         this._typeTable = {};
 
-        this.parent();
+        super._init(params);
         this.set_column_types([GdkPixbuf.Pixbuf,
                                GObject.TYPE_OBJECT,
                                GObject.TYPE_STRING,
@@ -75,22 +73,22 @@ var PlaceStore = new Lang.Class({
                                GObject.TYPE_DOUBLE]);
 
         this.set_sort_column_id(Columns.ADDED, Gtk.SortType.ASCENDING);
-    },
+    }
 
-    _addPlace: function(place, type) {
+    _addPlace(place, type) {
         this._setPlace(this.append(), place, type, new Date().getTime());
         this._store();
-    },
+    }
 
-    _addContact: function(place) {
+    _addContact(place) {
         if (this.exists(place, PlaceType.CONTACT)) {
             return;
         }
 
         this._addPlace(place, PlaceType.CONTACT);
-    },
+    }
 
-    _addFavorite: function(place) {
+    _addFavorite(place) {
         if (!place.store)
             return;
 
@@ -99,15 +97,15 @@ var PlaceStore = new Lang.Class({
         }
 
         if (this.exists(place, PlaceType.RECENT)) {
-            this._removeIf((function(model, iter) {
+            this._removeIf((model, iter) => {
                 let p = model.get_value(iter, Columns.PLACE);
                 return p.uniqueID === place.uniqueID;
-            }).bind(this), true);
+            }, true);
         }
         this._addPlace(place, PlaceType.FAVORITE);
-    },
+    }
 
-    _addRecent: function(place) {
+    _addRecent(place) {
         if (!place.store)
             return;
 
@@ -119,7 +117,7 @@ var PlaceStore = new Lang.Class({
         if (this._numRecentPlaces === this._recentPlacesLimit) {
             // Since we sort by added, the oldest recent will be
             // the first one we encounter.
-            this._removeIf((function(model, iter) {
+            this._removeIf((model, iter) => {
                 let type = model.get_value(iter, Columns.TYPE);
 
                 if (type === PlaceType.RECENT) {
@@ -129,13 +127,13 @@ var PlaceStore = new Lang.Class({
                     return true;
                 }
                 return false;
-            }).bind(this), true);
+            }, true);
         }
         this._addPlace(place, PlaceType.RECENT);
         this._numRecentPlaces++;
-    },
+    }
 
-    _addRecentRoute: function(stored) {
+    _addRecentRoute(stored) {
         if (this.exists(stored, PlaceType.RECENT_ROUTE))
             return;
 
@@ -143,7 +141,7 @@ var PlaceStore = new Lang.Class({
             return;
 
         if (this._numRecentRoutes >= this._recentRoutesLimit) {
-            this._removeIf((function(model, iter) {
+            this._removeIf((model, iter) => {
                 let type = model.get_value(iter, Columns.TYPE);
 
                 if (type === PlaceType.RECENT_ROUTE) {
@@ -153,13 +151,13 @@ var PlaceStore = new Lang.Class({
                     return true;
                 }
                 return false;
-            }).bind(this), true);
+            }, true);
         }
         this._addPlace(stored, PlaceType.RECENT_ROUTE);
         this._numRecentRoutes++;
-    },
+    }
 
-    load: function() {
+    load() {
         if (!GLib.file_test(this.filename, GLib.FileTest.EXISTS))
             return;
 
@@ -168,7 +166,7 @@ var PlaceStore = new Lang.Class({
             return;
         try {
             let jsonArray = JSON.parse(buffer);
-            jsonArray.forEach((function({ place, type, added }) {
+            jsonArray.forEach(({ place, type, added }) => {
                 // We expect exception to be thrown in this line when parsing
                 // gnome-maps 3.14 or below place stores since the "place"
                 // key is not present.
@@ -187,13 +185,13 @@ var PlaceStore = new Lang.Class({
                         this._numRecentPlaces++;
                 }
                 this._setPlace(this.append(), p, type, added);
-            }).bind(this));
+            });
         } catch (e) {
             throw new Error('failed to parse places file');
         }
-    },
+    }
 
-    addPlace: function(place, type) {
+    addPlace(place, type) {
         if (type === PlaceType.FAVORITE)
             this._addFavorite(place, type);
         else if (type === PlaceType.RECENT)
@@ -202,37 +200,37 @@ var PlaceStore = new Lang.Class({
             this._addContact(place, type);
         else if (type === PlaceType.RECENT_ROUTE)
             this._addRecentRoute(place);
-    },
+    }
 
-    removePlace: function(place, placeType) {
+    removePlace(place, placeType) {
         if (!this.exists(place, placeType))
             return;
 
-        this._removeIf((function(model, iter) {
+        this._removeIf((model, iter) => {
             let p = model.get_value(iter, Columns.PLACE);
             if (p.uniqueID === place.uniqueID) {
                 this._typeTable[place.uniqueID] = null;
                 return true;
             }
             return false;
-        }).bind(this), true);
+        }, true);
         this._store();
-    },
+    }
 
-    getModelForPlaceType: function(placeType) {
+    getModelForPlaceType(placeType) {
         let filter = new Gtk.TreeModelFilter({ child_model: this });
 
-        filter.set_visible_func(function(model, iter) {
+        filter.set_visible_func((model, iter) => {
             let type = model.get_value(iter, Columns.TYPE);
             return (type === placeType);
         });
 
         return filter;
-    },
+    }
 
-    _store: function() {
+    _store() {
         let jsonArray = [];
-        this.foreach(function(model, path, iter) {
+        this.foreach((model, path, iter) => {
             let place = model.get_value(iter, Columns.PLACE);
             let type = model.get_value(iter, Columns.TYPE);
             let added = model.get_value(iter, Columns.ADDED);
@@ -249,9 +247,9 @@ var PlaceStore = new Lang.Class({
         let buffer = JSON.stringify(jsonArray);
         if (!Utils.writeFile(this.filename, buffer))
             log('Failed to write places file!');
-    },
+    }
 
-    _setPlace: function(iter, place, type, added) {
+    _setPlace(iter, place, type, added) {
         this.set(iter,
                  [Columns.PLACE,
                   Columns.NAME,
@@ -263,33 +261,33 @@ var PlaceStore = new Lang.Class({
                   added]);
 
         if (place.icon !== null) {
-            Utils.load_icon(place.icon, _ICON_SIZE, (function(pixbuf) {
+            Utils.load_icon(place.icon, _ICON_SIZE, (pixbuf) => {
                 this.set(iter, [Columns.ICON], [pixbuf]);
-            }).bind(this));
+            });
         }
         this._typeTable[place.uniqueID] = type;
-    },
+    }
 
-    get: function(place) {
+    get(place) {
         let storedPlace = null;
 
-        this.foreach((function(model, path, iter) {
+        this.foreach((model, path, iter) => {
             let p = model.get_value(iter, Columns.PLACE);
             if (p.uniqueID === place.uniqueID) {
                 storedPlace = p;
                 return true;
             }
             return false;
-        }).bind(this));
+        });
         return storedPlace;
-    },
+    }
 
-    isStale: function(place) {
+    isStale(place) {
         if (!this.exists(place, null))
             return false;
 
         let added = null;
-        this.foreach(function(model, path, iter) {
+        this.foreach((model, path, iter) => {
             let p = model.get_value(iter, Columns.PLACE);
 
             if (p.uniqueID === place.uniqueID) {
@@ -302,28 +300,28 @@ var PlaceStore = new Lang.Class({
         let days = Math.abs(now - added) / _ONE_DAY;
 
         return (days >= _STALE_THRESHOLD);
-    },
+    }
 
-    exists: function(place, type) {
+    exists(place, type) {
         if (type !== undefined && type !== null && this._typeTable[place.uniqueID] !== undefined)
             return this._typeTable[place.uniqueID] === type;
         else
             return this._typeTable[place.uniqueID] !== undefined;
-    },
+    }
 
-    _removeIf: function(evalFunc, stop) {
-        this.foreach((function(model, path, iter) {
+    _removeIf(evalFunc, stop) {
+        this.foreach((model, path, iter) => {
             if (evalFunc(model, iter)) {
                 this.remove(iter);
                 if (stop)
                     return true;
             }
             return false;
-        }).bind(this));
-    },
+        });
+    }
 
-    updatePlace: function(place) {
-        this.foreach((function(model, path, iter) {
+    updatePlace(place) {
+        this.foreach((model, path, iter) => {
             let p = model.get_value(iter, Columns.PLACE);
 
             if (p.uniqueID === place.uniqueID) {
@@ -332,6 +330,6 @@ var PlaceStore = new Lang.Class({
                 this._store();
                 return;
             }
-        }).bind(this));
+        });
     }
 });
