@@ -24,7 +24,6 @@ const Cairo = imports.cairo;
 const Gdk = imports.gi.Gdk;
 const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
@@ -40,9 +39,7 @@ const TransitMoreRow = imports.transitMoreRow;
 const TransitOptionsPanel = imports.transitOptionsPanel;
 const Utils = imports.utils;
 
-var Sidebar = new Lang.Class({
-    Name: 'Sidebar',
-    Extends: Gtk.Revealer,
+var Sidebar = GObject.registerClass({
     Template: 'resource:///org/gnome/Maps/ui/sidebar.ui',
     InternalChildren: [ 'distanceInfo',
                         'entryList',
@@ -66,10 +63,11 @@ var Sidebar = new Lang.Class({
                         'transitItineraryListBox',
                         'transitItineraryBackButton',
                         'transitItineraryTimeLabel',
-                        'transitItineraryDurationLabel'],
+                        'transitItineraryDurationLabel']
+}, class Sidebar extends Gtk.Revealer {
 
-    _init: function(mapView) {
-        this.parent({ transition_type: Gtk.RevealerTransitionType.SLIDE_LEFT });
+    _init(mapView) {
+        super._init({ transition_type: Gtk.RevealerTransitionType.SLIDE_LEFT });
 
         this._mapView = mapView;
 
@@ -104,9 +102,9 @@ var Sidebar = new Lang.Class({
          */
         if (!Application.routingDelegator.openTripPlanner.enabled)
             this._modeTransitToggle.destroy();
-    },
+    }
 
-    _initTransportationToggles: function(pedestrian, bike, car, transit) {
+    _initTransportationToggles(pedestrian, bike, car, transit) {
         let transport = RouteQuery.Transportation;
 
         let onToggle = function(mode, button) {
@@ -143,9 +141,9 @@ var Sidebar = new Lang.Class({
 
         setToggles.bind(this)();
         this._query.connect('notify::transportation', setToggles.bind(this));
-    },
+    }
 
-    _switchRoutingMode: function(mode) {
+    _switchRoutingMode(mode) {
         if (mode === RouteQuery.Transportation.TRANSIT) {
             Application.routingDelegator.useTransit = true;
             this._linkButtonStack.visible_child_name = 'openTripPlanner';
@@ -158,25 +156,25 @@ var Sidebar = new Lang.Class({
             this._transitRevealer.reveal_child = false;
             Application.routingDelegator.openTripPlanner.plan.deselectItinerary();
         }
-    },
+    }
 
-    _initQuerySignals: function() {
-        this._query.connect('point-added', (function(obj, point, index) {
+    _initQuerySignals() {
+        this._query.connect('point-added', (obj, point, index) => {
             this._createRouteEntry(index, point);
-        }).bind(this));
+        });
 
-        this._query.connect('point-removed', (function(obj, point, index) {
+        this._query.connect('point-removed', (obj, point, index) => {
             let row = this._entryList.get_row_at_index(index);
             row.destroy();
-        }).bind(this));
-    },
+        });
+    }
 
-    _cancelStore: function() {
+    _cancelStore() {
         Mainloop.source_remove(this._storeRouteTimeoutId);
         this._storeRouteTimeoutId = 0;
-    },
+    }
 
-    _createRouteEntry: function(index, point) {
+    _createRouteEntry(index, point) {
         let type;
         if (index === 0)
             type = RouteEntry.Type.FROM;
@@ -191,57 +189,58 @@ var Sidebar = new Lang.Class({
         this._entryList.insert(routeEntry, index);
 
         if (type === RouteEntry.Type.FROM) {
-            routeEntry.button.connect('clicked', (function() {
+            routeEntry.button.connect('clicked', () => {
                 let lastIndex = this._entryList.get_children().length;
                 this._query.addPoint(lastIndex - 1);
-            }).bind(this));
+            });
 
-            this.bind_property('child-revealed',
-                               routeEntry.entry, 'has_focus',
-                               GObject.BindingFlags.DEFAULT);
+            this.connect('notify::child-revealed', () => {
+                if (this.child_revealed)
+                    routeEntry.entry.grab_focus_without_selecting();
+            });
         } else if (type === RouteEntry.Type.VIA) {
-            routeEntry.button.connect('clicked', (function() {
+            routeEntry.button.connect('clicked', () => {
                 let row = routeEntry.get_parent();
                 this._query.removePoint(row.get_index());
-            }).bind(this));
+            });
         } else if (type === RouteEntry.Type.TO) {
             routeEntry.button.connect('clicked',
                                       this._reverseRoutePoints.bind(this));
         }
 
         this._initRouteDragAndDrop(routeEntry);
-    },
+    }
 
-    _initInstructionList: function() {
+    _initInstructionList() {
         let route = Application.routingDelegator.graphHopper.route;
         let transitPlan = Application.routingDelegator.openTripPlanner.plan;
 
-        route.connect('reset', (function() {
+        route.connect('reset', () => {
             this._clearInstructions();
 
             let length = this._entryList.get_children().length;
             for (let index = 1; index < (length - 1); index++) {
                 this._query.removePoint(index);
             }
-        }).bind(this));
+        });
 
-        transitPlan.connect('reset', (function() {
+        transitPlan.connect('reset', () => {
             this._clearTransitOverview();
             this._showTransitOverview();
             this._instructionStack.visible_child = this._transitWindow;
             /* don't remove query points as with the turn-based routing,
              * since we might get "no route" because of the time selected
              * and so on */
-        }).bind(this));
+        });
 
-        transitPlan.connect('no-more-results', (function() {
+        transitPlan.connect('no-more-results', () => {
             // remove the "load more" row, keep the empty row since it gives the separator
             let numRows = this._transitOverviewListBox.get_children().length;
             let loadMoreRow = this._transitOverviewListBox.get_row_at_index(numRows - 2);
             this._transitOverviewListBox.remove(loadMoreRow);
-        }).bind(this));
+        });
 
-        this._query.connect('notify', (function() {
+        this._query.connect('notify', () => {
             if (this._query.isValid()) {
                 this._instructionStack.visible_child = this._instructionSpinner;
             } else {
@@ -256,15 +255,15 @@ var Sidebar = new Lang.Class({
             if (this._storeRouteTimeoutId)
                 this._cancelStore();
 
-        }).bind(this));
+        });
 
-        route.connect('update', (function() {
+        route.connect('update', () => {
             this._clearInstructions();
 
             if (this._storeRouteTimeoutId)
                 this._cancelStore();
 
-            this._storeRouteTimeoutId = Mainloop.timeout_add(5000, (function() {
+            this._storeRouteTimeoutId = Mainloop.timeout_add(5000, () => {
                 let placeStore = Application.placeStore;
                 let places = this._query.filledPoints.map(function(point) {
                     return point.place;
@@ -281,32 +280,32 @@ var Sidebar = new Lang.Class({
                                         PlaceStore.PlaceType.RECENT_ROUTE);
                 }
                 this._storeRouteTimeoutId = 0;
-            }).bind(this));
+            });
 
-            route.turnPoints.forEach((function(turnPoint) {
+            route.turnPoints.forEach((turnPoint) => {
                 let row = new InstructionRow.InstructionRow({ visible: true,
                                                               turnPoint: turnPoint });
                 this._instructionList.add(row);
-            }).bind(this));
+            });
 
             /* Translators: %s is a time expression with the format "%f h" or "%f min" */
             this._timeInfo.label = _("Estimated time: %s").format(Utils.prettyTime(route.time));
             this._distanceInfo.label = Utils.prettyDistance(route.distance);
-        }).bind(this));
+        });
 
-        this._instructionList.connect('row-selected',(function(listbox, row) {
+        this._instructionList.connect('row-selected', (listbox, row) => {
             if (row)
                 this._mapView.showTurnPoint(row.turnPoint);
-        }).bind(this));
+        });
 
-        transitPlan.connect('update', (function() {
+        transitPlan.connect('update', () => {
             this._clearTransitOverview();
             this._showTransitOverview();
             this._populateTransitItineraryOverview();
-        }).bind(this));
+        });
 
         /* use list separators for the transit itinerary overview list */
-        this._transitOverviewListBox.set_header_func(function(row, prev) {
+        this._transitOverviewListBox.set_header_func((row, prev) => {
             if (prev)
                 row.set_header(new Gtk.Separator());
         });
@@ -316,75 +315,75 @@ var Sidebar = new Lang.Class({
         this._transitItineraryBackButton.connect('clicked',
                                                  this._showTransitOverview.bind(this));
 
-    },
+    }
 
-    _clearTransitOverview: function() {
+    _clearTransitOverview() {
         let listBox = this._transitOverviewListBox;
         listBox.forall(listBox.remove.bind(listBox));
 
         this._instructionStack.visible_child = this._transitWindow;
         this._timeInfo.label = '';
         this._distanceInfo.label = '';
-    },
+    }
 
-    _clearTransitItinerary: function() {
+    _clearTransitItinerary() {
         let listBox = this._transitItineraryListBox;
         listBox.forall(listBox.remove.bind(listBox));
-    },
+    }
 
-    _showTransitOverview: function() {
+    _showTransitOverview() {
         let plan = Application.routingDelegator.openTripPlanner.plan;
 
         this._transitListStack.visible_child_name = 'overview';
         this._transitHeader.visible_child_name = 'options';
         plan.deselectItinerary();
-    },
+    }
 
-    _showTransitItineraryView: function() {
+    _showTransitItineraryView() {
         this._transitListStack.visible_child_name = 'itinerary';
         this._transitHeader.visible_child_name = 'itinerary-header';
-    },
+    }
 
-    _populateTransitItineraryOverview: function() {
+    _populateTransitItineraryOverview() {
         let plan = Application.routingDelegator.openTripPlanner.plan;
 
-        plan.itineraries.forEach((function(itinerary) {
+        plan.itineraries.forEach((itinerary) => {
             let row =
                 new TransitItineraryRow.TransitItineraryRow({ visible: true,
                                                               itinerary: itinerary });
             this._transitOverviewListBox.add(row);
-        }).bind(this));
+        });
         /* add the "load more" row */
         this._transitOverviewListBox.add(
             new TransitMoreRow.TransitMoreRow({ visible: true }));
 
         /* add an empty list row to get a final separator */
         this._transitOverviewListBox.add(new Gtk.ListBoxRow({ visible: true }));
-    },
+    }
 
-    _onItineraryActivated: function(itinerary) {
+    _onItineraryActivated(itinerary) {
         let plan = Application.routingDelegator.openTripPlanner.plan;
 
         this._populateTransitItinerary(itinerary);
         this._showTransitItineraryView();
         plan.selectItinerary(itinerary);
-    },
+    }
 
-    _onMoreActivated: function(row) {
+    _onMoreActivated(row) {
         row.startLoading();
         Application.routingDelegator.openTripPlanner.fetchMoreResults();
-    },
+    }
 
-    _onItineraryOverviewRowActivated: function(listBox, row) {
+    _onItineraryOverviewRowActivated(listBox, row) {
         this._transitOverviewListBox.unselect_all();
 
         if (row.itinerary)
             this._onItineraryActivated(row.itinerary);
         else
             this._onMoreActivated(row);
-    },
+    }
 
-    _populateTransitItinerary: function(itinerary) {
+    _populateTransitItinerary(itinerary) {
         this._transitItineraryTimeLabel.label =
             itinerary.prettyPrintTimeInterval();
         this._transitItineraryDurationLabel.label =
@@ -403,20 +402,20 @@ var Sidebar = new Lang.Class({
         this._transitItineraryListBox.add(
             new TransitArrivalRow.TransitArrivalRow({ itinerary: itinerary,
                                                       mapView: this._mapView }));
-    },
+    }
 
 
-    _clearInstructions: function() {
+    _clearInstructions() {
         let listBox = this._instructionList;
         listBox.forall(listBox.remove.bind(listBox));
 
         this._instructionStack.visible_child = this._instructionWindow;
         this._timeInfo.label = '';
         this._distanceInfo.label = '';
-    },
+    }
 
     // Iterate over points and establish the new order of places
-    _reorderRoutePoints: function(srcIndex, destIndex) {
+    _reorderRoutePoints(srcIndex, destIndex) {
         let points = this._query.points;
         let srcPlace = this._draggedPoint.place;
 
@@ -433,13 +432,13 @@ var Sidebar = new Lang.Class({
         }
 
         this._query.thaw_notify();
-    },
+    }
 
     /* The reason we don't just use the array .reverse() function is that we
      * need to update the place parameters on the actual point objects in the
      * array to fire the query notify signal that will iniate an update.
      */
-    _reverseRoutePoints: function() {
+    _reverseRoutePoints() {
         let points = this._query.points;
         let length = points.length;
 
@@ -452,28 +451,28 @@ var Sidebar = new Lang.Class({
             points[length - i - 1].place = p1;
         }
         this._query.thaw_notify();
-    },
+    }
 
-    _onDragDrop: function(row, context, x, y, time) {
+    _onDragDrop(row, context, x, y, time) {
         let srcIndex = this._query.points.indexOf(this._draggedPoint);
         let destIndex = row.get_index();
 
         this._reorderRoutePoints(srcIndex, destIndex);
         Gtk.drag_finish(context, true, false, time);
         return true;
-    },
+    }
 
-    _dragHighlightRow: function(row) {
+    _dragHighlightRow(row) {
         row.opacity = 0.6;
-    },
+    }
 
-    _dragUnhighlightRow: function(row) {
+    _dragUnhighlightRow(row) {
         row.opacity = 1.0;
-    },
+    }
 
     // Set the opacity of the row we are currently dragging above
     // to semi transparent.
-    _onDragMotion: function(row, context, x, y, time) {
+    _onDragMotion(row, context, x, y, time) {
         let routeEntry = row.get_child();
 
         if (this._draggedPoint && this._draggedPoint !== routeEntry.point) {
@@ -482,19 +481,19 @@ var Sidebar = new Lang.Class({
         } else
             Gdk.drag_status(context, 0, time);
         return true;
-    },
+    }
 
     // Drag ends, show the dragged row again.
-    _onDragEnd: function(context, row) {
+    _onDragEnd(context, row) {
         this._draggedPoint = null;
 
         // Restore to natural height
         row.height_request = -1;
         row.get_child().show();
-    },
+    }
 
     // Drag begins, set the correct drag icon and hide the dragged row.
-    _onDragBegin: function(context, row) {
+    _onDragBegin(context, row) {
         let routeEntry = row.get_child();
         let dragEntry = this._dragWidget.get_child();
 
@@ -509,31 +508,31 @@ var Sidebar = new Lang.Class({
         dragEntry.entry.text = routeEntry.entry.text;
         Gtk.drag_set_icon_surface(context,
                                   this._dragWidget.get_surface(), 0, 0);
-    },
+    }
 
     // We add RouteEntry to an OffscreenWindow and paint the background
     // of the entry to be transparent. We can later use the GtkOffscreenWindow
     // method get_surface to generate our drag icon.
-    _initDragWidget: function() {
+    _initDragWidget() {
         let dragEntry = new RouteEntry.RouteEntry({ type: RouteEntry.Type.TO,
                                                     name: 'dragged-entry',
                                                     app_paintable: true });
         this._dragWidget = new Gtk.OffscreenWindow({ visible: true });
 
-        dragEntry.connect('draw', (function(widget, cr) {
+        dragEntry.connect('draw', (widget, cr) => {
             cr.setSourceRGBA(0.0, 0.0, 0.0, 0.0);
             cr.setOperator(Cairo.Operator.SOURCE);
             cr.paint();
             cr.setOperator(Cairo.Operator.OVER);
-        }).bind(this));
+        });
 
         this._dragWidget.add(dragEntry);
-    },
+    }
 
     // Set up drag and drop between RouteEntrys. The drag source is from a
     // GtkEventBox that contains the start/end icon next in the entry. And
     // the drag destination is the ListBox row.
-    _initRouteDragAndDrop: function(routeEntry) {
+    _initRouteDragAndDrop(routeEntry) {
         let dragIcon = routeEntry.iconEventBox;
         let row = routeEntry.get_parent();
 
@@ -547,12 +546,8 @@ var Sidebar = new Lang.Class({
                           Gdk.DragAction.MOVE);
         row.drag_dest_add_image_targets();
 
-        dragIcon.connect('drag-begin', (function(icon, context) {
-            this._onDragBegin(context, row);
-        }).bind(this));
-        dragIcon.connect('drag-end', (function(icon, context) {
-            this._onDragEnd(context, row);
-        }).bind(this));
+        dragIcon.connect('drag-begin', (icon, context) => this._onDragBegin(context, row));
+        dragIcon.connect('drag-end', (icon, context) => this._onDragEnd(context, row));
 
         row.connect('drag-leave', this._dragUnhighlightRow.bind(this, row));
         row.connect('drag-motion', this._onDragMotion.bind(this));
@@ -560,4 +555,4 @@ var Sidebar = new Lang.Class({
 
         this._initDragWidget();
     }
-})
+});
